**0.8.1 - 07/24/18**

 - Move to source layout.
 - Set tests to install first and then test installed package.
 - Renamed `test_util` to resolve naming collision during test.

**0.8.0 - 07/24/18**

 - Initial release
